==> tetzle_2.1.5+dfsg1.orig.tar.gz: tetzle-2.1.5+dfsg1/translations/tetzle_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Åpne bilde</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valg</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Avrundet utsnitt</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Kastskygger</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Farger</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Bakgrunn:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Skygge:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Framheving:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Mangler bilde.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Vent</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Laster bilde…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Genererer puslespill…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Oppretter brikker…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Laster puslespill…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Ukjent dataformat</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Ukjent element &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Kunne ikke tolke XML-fil.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Laster brikker…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Henter brikker…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Plasserer brikker…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Velg spill</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Nåværende spill</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nytt spill</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Billedegenskaper</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiketter:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Velg programspråk:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemforvalg&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Merk</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Språkvalg trer i effekt ved omstart av programmet.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Legg til bilde</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Fjern bilde</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Billedegenskaper</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 brikker</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopierer bilder…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Fjern valgt bilde?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Fjern valgt bilde?

Lagrede spill som bruker dette bildet vil også bli fjernet.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Uten tittel</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Uten tittel</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 brikker %2 %3% fullført</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Slett spill</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Slett valgt spill?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Oversikt</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Legg til etikett</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Fjern etikett</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Umerket</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Alle bilder</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Uten tittel %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørsmål</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Fjern valgt etikett?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Beklager</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>En etikett med det navnet finnes allerede.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spill</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Hent brikker</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Velg…</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>For&amp;størr</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>For&amp;minsk</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Tilpasning</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Vis &amp;oversikt</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Fane</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>F&amp;ullskjermsvisning</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Innstillinger</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Utseende…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;språk…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Kontroller</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Plukk opp brikker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Venstreklikk eller mellomrom</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Legg ned brikker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Velg brikker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Venstremusetastdragning</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Roter brikker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Høyreklikk, Ctrl+venstreklikk, eller R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Dra puslespill:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Midklikk, Shift+Venstreklikk, eller piltaster</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Forstørr bilde:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Rullehjul eller +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Flytt peker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Flytt mus eller W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Om Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Et puslespill som bruker tetromino-brikker</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Opphavsrett &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lisensiert &lt;a href=%1&gt;GPLv3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Velg OpenGL-versjon.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versjon</translation>
    </message>
</context>
</TS>

==> tetzle_2.2.3.orig.tar.gz: tetzle-2.2.3/translations/tetzle_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Åpne bilde</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valg</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Avrundet utsnitt</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Kastskygger</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Farger</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Bakgrunn:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Skygge:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Framheving:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Mangler bilde.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Vent</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Laster bilde…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Genererer puslespill…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Oppretter brikker…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Laster puslespill…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Ukjent dataformat</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Ukjent element &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Kunne ikke tolke XML-fil.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Laster brikker…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Henter brikker…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Plasserer brikker…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Velg spill</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Nåværende spill</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nytt spill</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Billedegenskaper</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiketter:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Velg programspråk:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemforvalg&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Merk</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Språkvalg trer i effekt ved omstart av programmet.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Legg til bilde</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Fjern bilde</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Billedegenskaper</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 brikker</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Kopierer bilder…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Fjern valgt bilde?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Fjern valgt bilde?

Lagrede spill som bruker dette bildet vil også bli fjernet.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Uten tittel</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Uten tittel</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 brikker %2 %3% fullført</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Slett spill</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Slett valgt spill?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Oversikt</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Legg til etikett</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Fjern etikett</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Umerket</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Alle bilder</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Uten tittel %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Spørsmål</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Fjern valgt etikett?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Beklager</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>En etikett med det navnet finnes allerede.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spill</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Hent brikker</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Velg…</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>For&amp;størr</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>For&amp;minsk</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>&amp;Tilpasning</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Vis &amp;oversikt</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Fane</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>F&amp;ullskjermsvisning</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Innstillinger</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Utseende…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;språk…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Kontroller</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Plukk opp brikker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Venstreklikk eller mellomrom</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Legg ned brikker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Velg brikker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Venstremusetastdragning</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Roter brikker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Høyreklikk, Ctrl+venstreklikk, eller R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Dra puslespill:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Midklikk, Shift+Venstreklikk, eller piltaster</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Forstørr bilde:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Rullehjul eller +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Flytt peker:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Flytt mus eller W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Om Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Et puslespill som bruker tetromino-brikker</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Opphavsrett &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lisensiert &lt;a href=%1&gt;GPLv3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Velg OpenGL-versjon.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versjon</translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
